@@ -1,7 +1,12 @@
 import logging
 import logging.config
+from colorama import init
 from commitizen.cz.base import BaseCommitizen
 
+
+init()
+
+
 LOGGING = {
     "version": 1,
     "disable_existing_loggers": True,
